@@ -3,11 +3,11 @@ from __future__ import annotations
 import logging
 from typing import TYPE_CHECKING, final
 
-from cartographer.adapters.klipper.axis_twist_compensation import KlipperAxisTwistCompensationHelper
+from cartographer.adapters.klipper.axis_twist_compensation import KlipperAxisTwistCompensationAdapter
 from cartographer.adapters.klipper.bed_mesh import KlipperBedMesh
 from cartographer.adapters.klipper.configuration import KlipperConfiguration
 from cartographer.adapters.klipper.gcode import KlipperGCodeDispatch
-from cartographer.adapters.klipper.mcu import KlipperCartographerMcu
+from cartographer.adapters.klipper.mcu.mcu import KlipperCartographerMcu
 from cartographer.adapters.klipper.task_executor import KlipperMultiprocessingExecutor
 from cartographer.adapters.klipper.toolhead import KlipperToolhead
 from cartographer.runtime.adapters import Adapters
@@ -34,4 +34,4 @@ class KlipperAdapters(Adapters):
 
         self.axis_twist_compensation = None
         if config.has_section("axis_twist_compensation"):
-            self.axis_twist_compensation = KlipperAxisTwistCompensationHelper(config)
+            self.axis_twist_compensation = KlipperAxisTwistCompensationAdapter(config)
