@@ -16,7 +16,7 @@ if TYPE_CHECKING:
     from stepper import MCU_stepper
     from toolhead import ToolHead as KlippyToolhead
 
-    from cartographer.adapters.klipper.mcu import KlipperCartographerMcu
+    from cartographer.adapters.klipper.mcu.mcu import KlipperCartographerMcu
 
 logger = logging.getLogger(__name__)
 
@@ -156,9 +156,3 @@ class KlipperToolhead(Toolhead):
         time = self.mcu.get_current_time()
         heater = self.toolhead.get_extruder().get_heater().get_status(time)
         return TemperatureStatus(heater["temperature"], heater["target"])
-
-    @override
-    def apply_axis_twist_compensation(self, position: Position) -> Position:
-        pos = position.as_list()
-        self.printer.send_event("probe:update_results", pos)
-        return Position(pos[0], pos[1], pos[2])
