@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import logging
 
+from cartographer import __version__
 from cartographer.core import PrinterCartographer
 from cartographer.runtime.loader import init_adapter, init_integrator
 
@@ -24,4 +25,7 @@ def load_config(config: object) -> object:
     integrator.register_coil_temperature_sensor()
     integrator.register_endstop_pin("probe", "z_virtual_endstop", cartographer.scan_mode)
 
+    integrator_name = integrator.__class__.__name__
+    logger.info("Loaded Cartographer3D Plugin version %s using %s", __version__, integrator_name)
+
     return cartographer
