@@ -7,6 +7,7 @@ import numpy as np
 from typing_extensions import override
 
 from cartographer.interfaces.printer import Macro, MacroParams, Toolhead
+from cartographer.toolhead import BacklashCompensatingToolhead
 
 if TYPE_CHECKING:
     from numpy.typing import NDArray
@@ -16,8 +17,6 @@ if TYPE_CHECKING:
 
 logger = logging.getLogger(__name__)
 
-NOISE_THRESHOLD = 0.005  # mm, threshold for noise in backlash measurement
-
 
 @final
 class EstimateBacklashMacro(Macro):
@@ -25,7 +24,7 @@ class EstimateBacklashMacro(Macro):
 
     def __init__(self, toolhead: Toolhead, scan: ScanMode, config: Configuration) -> None:
         self._scan = scan
-        self._toolhead = toolhead
+        self._toolhead = toolhead.toolhead if isinstance(toolhead, BacklashCompensatingToolhead) else toolhead
         self._config = config
 
     @override
@@ -39,7 +38,7 @@ class EstimateBacklashMacro(Macro):
         self._toolhead.move(z=height, speed=speed)
         if calibrate:
             x, y = self._config.bed_mesh.zero_reference_position
-            self._toolhead.move(x=x, y=y, speed=speed)
+            self._toolhead.move(x=x, y=y, speed=self._config.general.travel_speed)
         self._toolhead.wait_moves()
 
         samples: dict[Literal["up", "down"], list[float]] = {"up": [], "down": []}
@@ -65,15 +64,13 @@ class EstimateBacklashMacro(Macro):
         t_stat, df = welchs_ttest(samples["down"], samples["up"])
 
         logger.debug(
-            """
-            Backlash estimation details (%d iterations):\n
-            Mean after moving up:     %.5f mm\n
-            Mean after moving down:   %.5f mm\n
-            Std dev (up):             %.5f mm\n
-            Std dev (down):           %.5f mm\n
-            Estimated raw backlash:   %.5f mm\n
-            Welch's t-test: t=%.5f, df=%.2f"
-            """,
+            "Backlash estimation details (%d iterations):\n"
+            "Mean after moving up:     %.5f mm\n"
+            "Mean after moving down:   %.5f mm\n"
+            "Std dev (up):             %.5f mm\n"
+            "Std dev (down):           %.5f mm\n"
+            "Estimated raw backlash:   %.5f mm\n"
+            "Welch's t-test: t=%.5f, df=%.2f",
             iterations,
             mean_up,
             mean_down,
@@ -87,28 +84,22 @@ class EstimateBacklashMacro(Macro):
         if abs(t_stat) < 2.0:
             backlash = 0.0
             logger.info(
-                """
-                Backlash test over %d samples found no significant difference (|t|=%.2f).
-                """,
+                "Backlash test over %d samples found no significant difference (|t|=%.2f).",
                 iterations,
                 abs(t_stat),
             )
         else:
             logger.info(
-                """
-                Backlash test over %d samples detected a consistent %.3f mm difference.
-                """,
+                "Backlash test over %d samples detected a consistent %.3f mm difference.",
                 iterations,
                 backlash,
             )
 
         if backlash < 0:
             logger.warning(
-                """
-                Estimated backlash is negative (%.5f mm), which is unexpected.
-                This suggests up moves measured higher than down moves.
-                Check for looseness or mechanical slop. Ignoring result.
-                """,
+                "Estimated backlash is negative (%.5f mm), which is unexpected.\n"
+                "This suggests up moves measured higher than down moves."
+                "Check for looseness or mechanical slop. Ignoring result.",
                 backlash,
             )
             return
@@ -117,25 +108,21 @@ class EstimateBacklashMacro(Macro):
             self._config.save_z_backlash(backlash)
             if backlash == 0.0:
                 logger.info(
-                    """
-                    Backlash calibration complete: no compensation required.
-                    Your printer appears mechanically tight.
-                    The SAVE_CONFIG command will update your config and restart the printer.
-                    """
+                    "Backlash calibration complete: no compensation required.\n"
+                    "Your printer appears mechanically tight.\n"
+                    "The SAVE_CONFIG command will update your config and restart the printer."
                 )
             else:
                 logger.info(
-                    """
-                    Backlash calibration complete: %.3f mm compensation will be used.
-                    The SAVE_CONFIG command will update your config and restart the printer.
-                    """,
+                    "Backlash calibration complete: %.3f mm compensation will be used.\n"
+                    "The SAVE_CONFIG command will update your config and restart the printer.",
                     backlash,
                 )
 
 
 def welchs_ttest(a_in: list[float], b_in: list[float]) -> tuple[float, float]:
-    a: NDArray[np.float64] = np.array(a_in, dtype=float)
-    b: NDArray[np.float64] = np.array(b_in, dtype=float)
+    a: NDArray[np.float_] = np.asarray(a_in, dtype=float)
+    b: NDArray[np.float_] = np.asarray(b_in, dtype=float)
 
     mean_a = np.mean(a)
     mean_b = np.mean(b)
