@@ -121,7 +121,7 @@ class TouchMode(TouchModelSelectorMixin, ProbeMode, Endstop):
         self.last_z_result: float | None = None
 
     @override
-    def get_status(self, eventtime: float) -> object:
+    def get_status(self, eventtime: float) -> dict[str, object]:
         return {
             "current_model": self.get_model().name if self.has_model() else "none",
             "models": ", ".join(self._config.models.keys()),
@@ -178,7 +178,7 @@ class TouchMode(TouchModelSelectorMixin, ProbeMode, Endstop):
         if self._toolhead.get_position().z < RETRACT_DISTANCE:
             self._toolhead.move(z=RETRACT_DISTANCE, speed=5)
         self._toolhead.wait_moves()
-        trigger_pos = self._toolhead.z_homing_move(self, speed=model.speed)
+        trigger_pos = self._toolhead.z_probing_move(self, speed=model.speed)
         pos = self._toolhead.get_position()
         self._toolhead.move(z=max(pos.z + RETRACT_DISTANCE, RETRACT_DISTANCE), speed=5)
         return trigger_pos - model.z_offset
@@ -209,7 +209,6 @@ class TouchMode(TouchModelSelectorMixin, ProbeMode, Endstop):
         if not homing_state.is_homing_z():
             return
 
-        homing_state.set_z_homed_position(self.get_model().z_offset)
         self._last_homing_time = self._toolhead.get_last_move_time()
 
     @override
@@ -226,19 +225,17 @@ class TouchMode(TouchModelSelectorMixin, ProbeMode, Endstop):
         return self.offset.z
 
     def _log_sample_stats(self, message: str, samples: Sequence[float]) -> None:
-        max_v, min_v = max(samples), min(samples)
+        max_v, min_v = max(samples, default=float("inf")), min(samples, default=float("-inf"))
         mean = np.mean(samples)
         median = np.median(samples)
         range_v = max_v - min_v
         std_dev = np.std(samples)
         mad = compute_mad(samples)
         logger.debug(
-            """
-                %s: (%s)
-                maximum %.6f, minimum %.6f, range %.6f,
-                average %.6f, median %.6f, standard deviation %.6f,
-                median absolute deviation %.6f
-                """,
+            "%s: (%s)\n"
+            "maximum %.6f, minimum %.6f, range %.6f,\n"
+            "average %.6f, median %.6f,\n"
+            "standard deviation %.6f, median absolute deviation %.6f",
             message,
             ", ".join(f"{s:.6f}" for s in samples),
             max_v,
